<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.1">
<context>
    <name>PIM_Handler</name>
    <message>
        <location filename="../PIM_handler.cpp" line="59"/>
        <source>Last Name</source>
        <translation>Efternavn</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="60"/>
        <source>First Name</source>
        <translation>Fornavn</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="61"/>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="62"/>
        <source>Mobile</source>
        <translation>Mobilnummer</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="63"/>
        <source>Phone</source>
        <translation>Telefon</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="64"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="65"/>
        <source>City</source>
        <translation>By</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="66"/>
        <source>ZIP Code</source>
        <translation>Postnummer</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="67"/>
        <source>State/Region</source>
        <translation>Delstat/region</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="68"/>
        <source>Country</source>
        <translation>Land</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="69"/>
        <source>Home Page</source>
        <translation>Hjemmeside</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="70"/>
        <source>Custom 1</source>
        <translation>Brugerdefineret 1</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="71"/>
        <source>Custom 2</source>
        <translation>Brugerdefineret 2</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="72"/>
        <source>Custom 3</source>
        <translation>Brugerdefineret 3</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="114"/>
        <source>Insert Personal Information</source>
        <translation>Indsæt personlige oplysninger</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="135"/>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
</context>
<context>
    <name>PIM_Settings</name>
    <message>
        <location filename="../PIM_settings.ui" line="14"/>
        <source>PIM Settings</source>
        <translation>PIM-indstillinger</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="42"/>
        <source>&lt;h2&gt;Personal Information Manager&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Håndtering af personlige oplysninger&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="64"/>
        <source>Your personal information that will be used on webpages.</source>
        <translation>Dine personlige oplysninger, der vil blive anvendt på hjemmesider.</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="76"/>
        <source>First Name:</source>
        <translation>Fornavn:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="89"/>
        <source>Last Name:</source>
        <translation>Efternavn:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="102"/>
        <source>E-mail:</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="115"/>
        <source>Phone:</source>
        <translation>Telefon:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="128"/>
        <source>Mobile Phone:</source>
        <translation>Mobilnummer:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="141"/>
        <source>Address:</source>
        <translation>Adresse:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="154"/>
        <source>City:</source>
        <translation>By:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="167"/>
        <source>ZIP Code:</source>
        <translation>Postnummer:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="180"/>
        <source>State/Region:</source>
        <translation>Delstat/region:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="193"/>
        <source>Country:</source>
        <translation>Land:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="206"/>
        <source>Home Page:</source>
        <translation>Hjemmeside:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="219"/>
        <source>Custom 1:</source>
        <translation>Brugerdefineret 1:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="232"/>
        <source>Custom 2:</source>
        <translation>Brugerdefineret 2:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="245"/>
        <source>Custom 3:</source>
        <translation>Brugerdefineret 3:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="260"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Press Ctrl+ENTER to autofill form fields for which QupZilla finds personal entries.</source>
        <translation>&lt;b&gt;Bemærk:&lt;/b&gt;Tryk på Ctrl+Enter for at udfylde formularfelter automatisk, når QupZilla finder personoplysninger.</translation>
    </message>
</context>
</TS>